package com.chartexample.androiddatachartexample;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.Fragment;
import android.graphics.Color;
import android.graphics.Matrix;
import android.graphics.drawable.GradientDrawable;
import android.os.Bundle;
import android.view.Display;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.infragistics.controls.CategoryDateTimeXAxis;
import com.infragistics.controls.CategoryXAxis;
import com.infragistics.controls.ChartDataContext;
import com.infragistics.controls.ChartToolTipAdapter;
import com.infragistics.controls.CustomContentUpdateInfo;
import com.infragistics.controls.DataChartView;
import com.infragistics.controls.ItemToolTipLayer;
import com.infragistics.controls.LineSeries;
import com.infragistics.controls.NumericYAxis;
import com.infragistics.controls.Series;
import com.infragistics.graphics.Brush;
import com.infragistics.graphics.Point;
import com.infragistics.graphics.Rect;
import com.infragistics.graphics.SolidColorBrush;

import java.text.DecimalFormat;
import java.util.Calendar;
import java.util.GregorianCalendar;


public class ChartActivity extends Activity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_chart);
        if (savedInstanceState == null) {
            getFragmentManager().beginTransaction()
                    .add(R.id.container, new PlaceholderFragment())
                    .commit();
        }
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.chart, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();
        if (id == R.id.action_settings) {
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    /**
     * A placeholder fragment containing a simple view.
     */
    public static class PlaceholderFragment extends Fragment {

        public PlaceholderFragment() {
        }

        View.OnTouchListener myhandler1 = new View.OnTouchListener() {
            public boolean onTouch(View v, MotionEvent event)  {

                MotionEvent.PointerCoords coords = new MotionEvent.PointerCoords();
                event.getPointerCoords(0, coords);

                DataChartView chart = (DataChartView)v;
                ItemToolTipLayer layer = (ItemToolTipLayer)chart.getSeriesAt(0);

                Rect viewportRect = chart.getViewportRect();

                Point touchPoint = new Point(coords.x, coords.y);

                Point relTouchPoint = new Point(touchPoint.getX() - viewportRect.getX(),
                        touchPoint.getY() - viewportRect.getY());

                layer.setCursorPosition(new Point(relTouchPoint.getX() / viewportRect.getWidth(),
                        relTouchPoint.getY() / viewportRect.getHeight()));

                return false;
            }
        };

        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container,
                Bundle savedInstanceState) {
            View rootView = inflater.inflate(R.layout.fragment_chart, container, false);

            TestData data = new TestData();

            DataChartView chart = new DataChartView(rootView.getContext());
            chart.setHorizontalZoomable(true);
            chart.setVerticalZoomable(true);
            chart.setOnTouchListener(myhandler1);
            chart.setOnSeriesPointerDownListener(new MySeriesClickListener());

            // X Axis
            CategoryDateTimeXAxis xAxis = new CategoryDateTimeXAxis();
            chart.addAxis(xAxis);
            xAxis.setDataSource(data);
            xAxis.setDateTimeMemberPath("Date");
            xAxis.setLabel("Date:D");
            xAxis.setOnFormatLabelListener(new OnAxisDateLabelListener());

            Calendar minCalendar = new GregorianCalendar();
            minCalendar.set(Calendar.YEAR, 2014);
            minCalendar.set(Calendar.MONTH, 6);
            minCalendar.set(Calendar.DAY_OF_MONTH, 30);

            Calendar maxCalendar = new GregorianCalendar();
            maxCalendar.set(Calendar.YEAR, 2014);
            maxCalendar.set(Calendar.MONTH, 8);
            maxCalendar.set(Calendar.DAY_OF_MONTH, 3);

            xAxis.setMinimumValue(minCalendar);
            xAxis.setMaximumValue(maxCalendar);
            xAxis.setInterval(1296000000);

            // Y Axis
            NumericYAxis yAxis = new NumericYAxis();



            chart.addAxis(yAxis);

            LineSeries lineSeries = new LineSeries();
            lineSeries.setXAxis(xAxis);
            lineSeries.setYAxis(yAxis);
            lineSeries.setValueMemberPath("Value");
            lineSeries.setDataSource(data);

            ItemToolTipLayer layer = new ItemToolTipLayer();
            layer.setTransitionDuration(0);
            layer.setTransitionInDuration(0);
            layer.setUseInterpolation(false);
            chart.addSeries(layer);

            final Activity activity = getActivity();

            ChartToolTipAdapter tooltip = new ChartToolTipAdapter(activity) {
                @SuppressLint("NewApi")
                @Override
                public View getView(ChartDataContext chartContext, View existingView, CustomContentUpdateInfo updateInfo) {
                    TextView tv;
                    LinearLayout lin = (LinearLayout)existingView;
                    if (lin == null) {
                        lin = new LinearLayout(activity);
                        lin.setBackgroundColor(Color.TRANSPARENT);
                        existingView = lin;
                        tv = new TextView(activity);
                        tv.setPadding(4, 4, 4, 4);

                        GradientDrawable gd = new GradientDrawable();
                        Brush brush = chartContext.getSeries().getActualBrush();
                        int c;
                        c = Color.BLACK;
                        if (brush != null && brush instanceof SolidColorBrush)
                        {
                            SolidColorBrush b = (SolidColorBrush)brush;
                            c = b.getColor();
                        }

                        gd.setColor(c);
                        FrameLayout fl = new FrameLayout(activity);
                        LinearLayout.LayoutParams pm = new LinearLayout.LayoutParams(30, 30);
                        pm.gravity = Gravity.CENTER_VERTICAL;
                        fl.setPadding(4, 4, 4, 4);
                        fl.setLayoutParams(pm);

                        fl.setBackgroundDrawable(gd);

                        lin.addView(fl);
                        lin.addView(tv);
                    }
                    else {
                        tv = (TextView)((LinearLayout)existingView).getChildAt(1);
                    }

                    String valueText = "";
                    TestDataItem it = (TestDataItem)chartContext.getItem();
                    if (it != null) {
                        String val = new DecimalFormat("#.00").format(it.getValue());
                        if (val == null) {
                            val = "NaN";
                        }
                        tv.setText(val);
                    }

                    return existingView;
                }
            };

            lineSeries.setToolTip(tooltip);

            chart.addSeries(lineSeries);

            return (chart);
        }
    }
}
